/* FileAttr,  Version 1.01                  */
/* Cloned from the Norton Utilities for DOS */
/* Display files with specified attributes, */
/* and/or set the specified attributes      */
/* Written by Rob van der Woude             */
/* http://www.robvanderwoude.com            */

/* Initialize RexxUtil */
if RxFuncQuery( "SysLoadFuncs" ) <> 0 then do
	call RxFuncAdd "SysLoadFuncs", "RexxUtil", "SysLoadFuncs"
	call SysLoadFuncs
end

/* Command line parsing */
parse upper arg filespec parameters
if filespec = "" then filespec = "*"
Alist = "*"
Hlist = "*"
Rlist = "*"
Slist = "*"
Aset  = "*"
Hset  = "*"
Rset  = "*"
Sset  = "*"
if pos( "+", parameters ) > 0 then do
	if pos( "A+", parameters ) > 0 then do
		Aset  = "+"
	end
	if pos( "H+", parameters ) > 0 then do
		Hset  = "+"
	end
	if pos( "R+", parameters ) > 0 then do
		Rset  = "+"
	end
	if pos( "S+", parameters ) > 0 then do
		Sset  = "+"
	end
	if pos( "+A", parameters ) > 0 then do
		Alist = "+"
	end
	if pos( "+H", parameters ) > 0 then do
		Hlist = "+"
	end
	if pos( "+R", parameters ) > 0 then do
		Rlist = "+"
	end
	if pos( "+S", parameters ) > 0 then do
		Slist = "+"
	end
end
if pos( "-", parameters ) > 0 then do
	if pos( "A-", parameters ) > 0 then do
		Aset  = "-"
	end
	if pos( "H-", parameters ) > 0 then do
		Hset  = "-"
	end
	if pos( "R-", parameters ) > 0 then do
		Rset  = "-"
	end
	if pos( "S-", parameters ) > 0 then do
		Sset  = "-"
	end
	if pos( "-A", parameters ) > 0 then do
		Alist = "-"
	end
	if pos( "-H", parameters ) > 0 then do
		Hlist = "-"
	end
	if pos( "-R", parameters ) > 0 then do
		Rlist = "-"
	end
	if pos( "-S", parameters ) > 0 then do
		Slist = "-"
	end
end
if pos( "*", parameters ) > 0 then do
	if pos( "A*", parameters ) > 0 then do
		Aset  = "*"
	end
	if pos( "H*", parameters ) > 0 then do
		Hset  = "*"
	end
	if pos( "R*", parameters ) > 0 then do
		Rset  = "*"
	end
	if pos( "S*", parameters ) > 0 then do
		Sset  = "*"
	end
	if pos( "*A", parameters ) > 0 then do
		Alist = "*"
	end
	if pos( "*H", parameters ) > 0 then do
		Hlist = "*"
	end
	if pos( "*R", parameters ) > 0 then do
		Rlist = "*"
	end
	if pos( "*S", parameters ) > 0 then do
		Slist = "*"
	end
end

options = "F"
if pos( "/S", parameters ) > 0 then options = options||"S"
listattr = Alist||"*"||Hlist||Rlist||Slist
setattr  = Aset||"*"||Hset||Rset||Sset

call SysFileTree filespec, "file.", options, listattr, setattr
if file.0 > 0 then do i = 1 to file.0
	say substr( file.i, 30 )
end
EXIT

Syntax:
	say
	say " FileAttr,  Version 1.01"
	say " Inspired by the Norton Utilities for DOS"
	say " Display and/or change file attributes of specified files"
	say " Written by Rob van der Woude"
	say " http://www.robvanderwoude.com"
	say
	say " Usage:    FILEDATE  filespec  [ options ]"
	say " Options:  format id dAs d (display) is either *, - or +"
	say "                         A (attribute) can be A, H, R or S"
	say "                         s (set) is either *, - or +"
	say "           /S    include subdirectories"
	say
	say " Examples: *R-       make all files Read-only (set R attribute)"
	say "           -H+       show files that are not hidden and make"
	say "                     them hidden"
	say "           -A* *S+   set S (system) attribute of all files that"
	say "                     have their A (archive) attribute not set"
	EXIT 255
return
